@@ -25,10 +25,27 @@
 __docformat__ = "restructuredtext en"
 
 import hmac
+from itertools import izip
 
 from cubicweb import AuthenticationError
 from cubicweb.server.sources import native
 
+try:
+    from hmac import compare_digest
+except ImportError:
+    # python 3.3 has hmac.compare_digest, but older versions don't.
+    # this version should leak less timing information than the normal string
+    # equality check
+    # the expectation here is that both inputs are ascii strings of the same
+    # length
+    def compare_digest(expected, actual):
+        if len(expected) != len(actual):
+            return False
+        result = 0
+        for (a, b) in izip(expected, actual):
+            result |= ord(a) ^ ord(b)
+        return result == 0
+
 
 class UserSecretKeyAuthentifier(native.BaseAuthentifier):
     """ Provide an authentication procedure based on a private key ``token`` """
@@ -59,10 +76,10 @@ class UserSecretKeyAuthentifier(native.BaseAuthentifier):
             assert len(rset) == 1
             user_eid, secret_key = rset[0]
             expected_signature = hmac.new(str(secret_key), request).hexdigest()
-            if expected_signature == signature:
+            if compare_digest(expected_signature, signature):
                 return user_eid
             else:
-                self.info('request content signature check failed')
+                session.info('request content signature check failed')
         except Exception, exc:
             session.debug('authentication failure (%s)', exc)
         raise AuthenticationError('invalid credentials')
