@@ -37,13 +37,12 @@ import hmac
 import hashlib
 import requests
 import requests.auth
-from datetime import datetime
+from email.utils import formatdate
 
 def sign(req, token):
     headers_to_sign = ('Content-MD5', 'Content-Type', 'Date')
     to_sign = (req.method + req.url +
                ''.join(req.headers.get(field, '') for field in headers_to_sign))
-    print repr(to_sign)
     return hmac.new(token, to_sign).hexdigest()
 
 def md5(data):
@@ -59,14 +58,13 @@ class SignedRequestAuth(requests.auth.AuthBase):
         if r.method in ('PUT', 'POST'):
             r.headers['Content-MD5'] = md5(r.body or '')
         r.headers['Authorization'] = 'Cubicweb %s:%s' % (self.token_id, sign(r, self.secret))
-        print 'BODY=%r' % r.body
         return r
 
 def get(url, token_id, token):
     auth = SignedRequestAuth(token_id, token)
     resp = requests.get(url,
             headers={'Accept': 'text/plain',
-                     'Date': datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')},
+                     'Date': formatdate(usegmt=True)},
             auth=auth)
     return resp.json()
 
@@ -77,7 +75,7 @@ def post(url, token_id, token, data=None, files=None, **params):
         _cw_fields += files.keys()
     resp = requests.post(url,files=files, data=data, params=params,
             headers={'Accept': 'text/plain',
-                     'Date': datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')},
+                     'Date': formatdate(usegmt=True)},
             auth=auth)
     return resp.json()
 
